<template>
  <a-modal
    :title="title"
    :width="1200"
    :visible="visible"
    :confirmLoading="confirmLoading"
    @ok="handleOk"
    @cancel="handleCancel"
  >
    <a-spin :spinning="confirmLoading">
      <a-form-model ref="form" :label-col="labelCol" :wrapper-col="wrapperCol" :model="model" :rules="validatorRules">
        <!-- 主表单区域 -->
        <a-row class="form-row" :gutter="6">
          <a-col :lg="24">
            <a-form-model-item label="近期目标" prop="jqmb">
              <a-textarea
                v-model="model.jqmb"
                placeholder="Controlled autosize"
                :auto-size="{ minRows: 6, maxRows: 10 }"
              />
            </a-form-model-item>
          </a-col>
        </a-row>
      </a-form-model>
    </a-spin>

    <!--   选择用户  -->
  </a-modal>
</template>

<script>
import { postAction } from '@/api/manage'

export default {
  name: 'ProjectModal5',
  data() {
    return {
      title: '修改近期目标',
      visible: false,
      form: this.$form.createForm(this),
      userIds: 'admin',
      model: {},
      labelCol: {
        xs: { span: 24 },
        sm: { span: 5 },
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 16 },
      },
      confirmLoading: false,
      validatorRules: {
        jqmb: [{ required: true, message: '近期目标不能为空', trigger: 'blur' }],
      },
      url: {
        add: '/pro/summary/add',
      },
    }
  },
  created() {},
  watch: {},
  methods: {
    edit(record) {
      this.form.resetFields()
      this.visible = true
      //数据类型为近期目标
      record.type = 1
      this.model = Object.assign({}, record)
    },

    handleCancel() {
      this.close()
    },
    handleOk() {
      let that = this
      this.$refs.form.validate((valid) => {
        if (valid) {
          that.confirmLoading = true
          //add
          //每次修改都新增一条记录,清除多余字段
          that.model.id  = null
          that.model.createBy  = null
          that.model.createTime  = null
          that.model.updateBy  = null
          that.model.updateTime  = null

          postAction(this.url.add, that.model)
            .then((res) => {
              that.confirmLoading = false
              if (res.success) {
                that.close()
                that.$message.success(res.message)
                that.$emit('ok', res.result)
                that.close()
              } else {
                that.$message.warning(res.message)
              }
            })
            .finally(() => {
              that.confirmLoading = false
            })
        }
      })
    },
    close() {
      this.$emit('close')
      this.visible = false
    },
    handleAddUser() {},
    handleChangeUserCommon(v) {},
  },
}
</script>

<style scoped>
</style>